@@ -17,7 +17,7 @@ extern "C" {
 #endif
 
   SEXP SphereSystem(SEXP R_param, SEXP R_cond);
-  SEXP SimulateSpheresAndIntersect(SEXP R_param, SEXP R_cond);
+  SEXP SimulateSpheresAndIntersect(SEXP R_param, SEXP R_cond, SEXP R_n);
   SEXP GetSphereSystem(SEXP ext);
   SEXP SetupSphereSystem(SEXP R_vname, SEXP R_env, SEXP R_param, SEXP R_cond);
   SEXP IntersectSphereSystem(SEXP ext, SEXP R_n, SEXP R_z, SEXP R_intern);
@@ -47,7 +47,7 @@ public:
   void IntersectWithPlane(STGM::Intersectors<STGM::CSphere>::Type &objects, STGM::CPlane &plane, int intern);
 
   template<typename F> void simSpheres(F f, const char *label);
-  void simSpheresPerfect(double mx, double sdx, const char *label);
+  void simSpheresPerfect(double mx, double sdx, const char *label, int perfect);
 
   STGM::CBox3 & box() { return m_box; }
 
